@@ -7,16 +7,19 @@
 @description: 
 """
 
+import torch
+
 from .cifar import CIFAR
 from .fashionmnist import FashionMNIST
 from .imagenet import ImageNet
 from .general_dataset import GeneralDataset
+from .general_dataset_v2 import GeneralDatasetV2
 from .lmdb_dataset import LMDBDataset
 from .lmdb_imagenet import LMDBImageNet
-from .youyou import YYDataset
+from .mp_dataset import MPDataset
 
 
-def build_dataset(cfg, transform=None, target_transform=None, is_train=True):
+def build_dataset(cfg, transform=None, target_transform=None, is_train=True, **kwargs):
     dataset_name = cfg.DATASET.NAME
     data_root = cfg.DATASET.TRAIN_ROOT if is_train else cfg.DATASET.TEST_ROOT
     top_k = cfg.DATASET.TOP_K
@@ -35,12 +38,20 @@ def build_dataset(cfg, transform=None, target_transform=None, is_train=True):
                            top_k=top_k)
     elif dataset_name == 'GeneralDataset':
         dataset = GeneralDataset(data_root, transform=transform, target_transform=target_transform, top_k=top_k)
+    elif dataset_name == 'GeneralDatasetV2':
+        dataset = GeneralDatasetV2(data_root, transform=transform, target_transform=target_transform, top_k=top_k)
     elif dataset_name == 'LMDBDataset':
         dataset = LMDBDataset(data_root, transform=transform, target_transform=target_transform, top_k=top_k)
     elif dataset_name == 'LMDBImageNet':
         dataset = LMDBImageNet(data_root, transform=transform, target_transform=target_transform, top_k=top_k)
-    elif dataset_name == 'YouYou':
-        dataset = YYDataset(data_root, transform=transform, target_transform=target_transform, top_k=top_k)
+    elif dataset_name == 'MPDataset':
+        shuffle = cfg.DATALOADER.RANDOM_SAMPLE
+        num_gpus = cfg.NUM_GPUS
+        rank_id = kwargs.get('rank_id', 0)
+        epoch = kwargs.get('epoch', 0)
+
+        dataset = MPDataset(data_root, transform=transform, target_transform=target_transform, top_k=top_k,
+                            shuffle=shuffle, num_gpus=num_gpus, rank_id=rank_id, epoch=epoch, drop_last=is_train)
     else:
         raise ValueError(f"the dataset {dataset_name} does not exist")
 
