@@ -7,12 +7,10 @@
 @description: 
 """
 
-import numpy as np
-from PIL import Image
-
 from torch.utils.data import Dataset
 import torchvision.datasets as datasets
 
+from .util import default_converter
 from .evaluator.general_evaluator import GeneralEvaluator
 
 
@@ -28,8 +26,7 @@ class FashionMNIST(Dataset):
 
     def __getitem__(self, index: int):
         image, target = self.data_set.__getitem__(index)
-        if isinstance(image, Image.Image):
-            image = np.array(image)
+        default_converter(image, rgb=False)
 
         if self.transform is not None:
             image = self.transform(image)
